summaryrefslogtreecommitdiffstats
path: root/src/kvilib/core/kvi_pointerlist.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-28 18:31:12 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-28 18:31:12 +0000
commit0a80cfd57d271dd44221467efb426675fa470356 (patch)
tree6f503a31aa078eaf8fa015cf1749808529d49fc9 /src/kvilib/core/kvi_pointerlist.h
parent3329e5a804e28ef3f5eb51d1e7affdd5a508e8f2 (diff)
downloadkvirc-0a80cfd57d271dd44221467efb426675fa470356.tar.gz
kvirc-0a80cfd57d271dd44221467efb426675fa470356.zip
TQt4 port kvirc
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/kvirc@1238719 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/kvilib/core/kvi_pointerlist.h')
-rw-r--r--src/kvilib/core/kvi_pointerlist.h34
1 files changed, 17 insertions, 17 deletions
diff --git a/src/kvilib/core/kvi_pointerlist.h b/src/kvilib/core/kvi_pointerlist.h
index 381780c8..8b5cb9c5 100644
--- a/src/kvilib/core/kvi_pointerlist.h
+++ b/src/kvilib/core/kvi_pointerlist.h
@@ -32,13 +32,13 @@
//
//=============================================================================
-// Qt changes the collection classes too much and too frequently.
+// TQt changes the collection classes too much and too frequently.
// I think we need to be independent of that to the maximum degree possible.
// That's why we have our own fast pointer list class.
-// This does not depend on Qt AT ALL and has an interface similar
-// to the Qt<=3.x series. The pointer lists with the autodelete
+// This does not depend on TQt AT ALL and has an interface similar
+// to the TQt<=3.x series. The pointer lists with the autodelete
// feature was great and I don't completly understand why they have
-// been removed from Qt4 in favor of the value based non-autodeleting
+// been removed from TQt4 in favor of the value based non-autodeleting
// lists... anyway: here we go :)
#include "kvi_settings.h"
@@ -288,7 +288,7 @@ public:
/// Iterating over pointers is also very fast and this
/// class contains an internal iterator that allows to
/// write loops in a compact and clean way.
/// See the first(), next(), current() and findRef()
/// functions for the description of this feature.
///
/// There is also a non-const external iterator
@@ -297,11 +297,11 @@ public:
/// since the list provides the autoDelete() method
/// which vould implicitly violate constness.
/// If you have to deal with const objects then
-/// you need to use a QList instead.
+/// you need to use a TQList instead.
///
/// Your objects also do not need to support copy constructors
/// or >= operators. This class will work fine without them
-/// as opposed to a plain QList.
+/// as opposed to a plain TQList.
///
/// This class also supports automatic deletion of the inseted items.
/// See the setAutoDelete() and autoDelete() members for the
@@ -618,7 +618,7 @@ public:
///
/// Returns the current iteration item
/// A call to this function MUST be preceded by a call to
- /// first(),last(),at() or findRef()
+ /// first(),last(),at() or tqfindRef()
///
T * current()
{
@@ -628,9 +628,9 @@ public:
///
/// Returns the current iteration item
/// A call to this function should be preceded by a call to
- /// first(),last(),at() or findRef().
+ /// first(),last(),at() or tqfindRef().
/// This function will return a NULL pointer if the current
- /// item has been invalidated due to a remove operation.
+ /// item has been tqinvalidated due to a remove operation.
///
T * safeCurrent()
{
@@ -641,7 +641,7 @@ public:
///
/// Returns an iterator pointing to the current item in the list.
/// A call to this function MUST be preceded by a call to
- /// first(),last(),at() or findRef()
+ /// first(),last(),at() or tqfindRef()
///
KviPointerListIterator<T> iteratorAtCurrent()
{
@@ -652,7 +652,7 @@ public:
/// Sets the iteration pointer to the next item in the list
/// and returns that item (or 0 if the end of the list has been reached)
/// A call to this function MUST be preceded by a _succesfull_ call to
- /// first(),last(),at() or findRef().
+ /// first(),last(),at() or tqfindRef().
///
T * next()
{
@@ -666,7 +666,7 @@ public:
/// Sets the iteration pointer to the previous item in the list
/// and returns that item (or 0 if the beginning of the list has been reached)
/// A call to this function MUST be preceded by a _succesfull_ call to
- /// first(),last(),at() or findRef()
+ /// first(),last(),at() or tqfindRef()
///
T * prev()
{
@@ -715,7 +715,7 @@ public:
/// and returns its position (zero based index) in the list or -1 if the
/// item cannot be found
///
- int findRef(const T * d)
+ int tqfindRef(const T * d)
{
int ret = 0;
for(T * t = first();t;t = next())
@@ -945,7 +945,7 @@ public:
///
bool removeRef(const T * d)
{
- if(findRef(d) == -1)return false;
+ if(tqfindRef(d) == -1)return false;
removeCurrentSafe();
return true;
}
@@ -957,7 +957,7 @@ public:
///
void insertAfter(const T * ref,const T * d)
{
- if(findRef(ref) == -1)
+ if(tqfindRef(ref) == -1)
{
append(d);
return;
@@ -981,7 +981,7 @@ public:
///
void insertBefore(const T * ref,const T * d)
{
- if(findRef(ref) == -1)
+ if(tqfindRef(ref) == -1)
{
prepend(d);
return;
@@ -288,7 +288,7 @@ public:
/// class contains an internal iterator that allows to
/// write loops in a compact and clean way.
-/// See the first(), next(), current() and findRef()
+/// See the first(), next(), current() and tqfindRef()
/// functions for the description of this feature.
///